utils

package
v0.0.0-...-f59dcab Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 2, 2025 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

const (
	// DefaultSocketFilename is the location of the Unix domain socket for this CSI driver
	// for Kubelet to send requests.
	DefaultSocketFilename string = "unix:///var/lib/kubelet/plugins/csi-tkm/csi.sock"

	// DefaultImagePort is the location of port the Image Server will listen on for TKM
	// to send requests.
	DefaultImagePort string = ":50051"

	// DefaultCacheDir is the default root directory to store the expanded the Triton Kernel
	// images.
	DefaultCacheDir = "/run/tkm/caches"

	// DefaultCacheDir is the default root directory to store the expanded the Triton Kernel
	// images.
	ClusterScopedSubDir = "cluster-scoped"

	// TcvBinary is the location on the host of the TCV binary.
	TcvBinary = "tcv"
)

Variables

This section is empty.

Functions

func DirSize

func DirSize(path string) (int64, error)

DirSize calculates the total size of a directory and its subdirectories.

func InitializeLogging

func InitializeLogging(logLevel string) logr.Logger

func IsSourceBindMount

func IsSourceBindMount(namespace, name string, log logr.Logger) (bool, error)

func IsTargetBindMount

func IsTargetBindMount(target string, log logr.Logger) (bool, error)

Types

This section is empty.

Jump to